# eric7.EricNetwork.EricSslCertificatesInfoWidget

Module implementing a widget to show SSL certificate infos.

### Global Attributes

QSslCertificate

### Classes

EricSslCertificatesInfoWidget | Class implementing a widget to show SSL certificate infos.

### Functions

None

## EricSslCertificatesInfoWidget

Class implementing a widget to show SSL certificate infos.

### Derived from

QWidget, Ui_EricSslCertificatesInfoWidget

### Class Attributes

None

### Class Methods

None

### Methods

EricSslCertificatesInfoWidget | Constructor
__certificateString | Private method to prepare some text for display.
__formatHexString | Private method to format a hex string for display.
__hasExpired | Private method to check for a certificate expiration.
__serialNumber | Private slot to format the certificate serial number.
__showCertificate | Private method to show the SSL certificate information.
on_chainComboBox_activated | Private slot to show the certificate info for the selected entry.
showCertificate | Public method to show the SSL certificate information.
showCertificateChain | Public method to show the SSL certificates of a certificate chain.

### Static Methods

None

#### EricSslCertificatesInfoWidget (Constructor)

EricSslCertificatesInfoWidget(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### EricSslCertificatesInfoWidget.__certificateString

__certificateString(txt)

Private method to prepare some text for display.

txt (str)
  text to be displayed

Return:
  prepared text

Return Type:
  str

#### EricSslCertificatesInfoWidget.__formatHexString

__formatHexString(hexString)

Private method to format a hex string for display.

hexString (str)
  hex string to be formatted

Return:
  formatted string

Return Type:
  str

#### EricSslCertificatesInfoWidget.__hasExpired

__hasExpired(effectiveDate, expiryDate)

Private method to check for a certificate expiration.

effectiveDate (QDateTime)
  date the certificate becomes effective
expiryDate (QDateTime)
  date the certificate expires

Return:
  flag indicating the expiration status

Return Type:
  bool

#### EricSslCertificatesInfoWidget.__serialNumber

__serialNumber(cert)

Private slot to format the certificate serial number.

cert (QSslCertificate)
  reference to the SSL certificate

Return:
  formated serial number

Return Type:
  str

#### EricSslCertificatesInfoWidget.__showCertificate

__showCertificate(certificate)

Private method to show the SSL certificate information.

certificate (QSslCertificate)
  reference to the SSL certificate

#### EricSslCertificatesInfoWidget.on_chainComboBox_activated

on_chainComboBox_activated(index)

Private slot to show the certificate info for the selected entry.

index (int)
  number of the certificate in the certificate chain

#### EricSslCertificatesInfoWidget.showCertificate

showCertificate(certificate)

Public method to show the SSL certificate information.

certificate (QSslCertificate)
  reference to the SSL certificate

#### EricSslCertificatesInfoWidget.showCertificateChain

showCertificateChain(certificateChain)

Public method to show the SSL certificates of a certificate chain.

certificateChain (list of QSslCertificate)
  list od SSL certificates

Up